

#include <WiFi.h>
#include <WebServer.h>
#include <HardwareSerial.h>

HardwareSerial mySerial(0);

const char* ssid = "Sam";
const char* password = "samlaneyhome";

WebServer server(80);

void setup() {
  //Serial.begin(115200);
  mySerial.begin(9600, SERIAL_8N1, -1, -1);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.println("Connecting to WiFi...");
  }

  Serial.print("Connected to WiFi. IP Address: ");
  Serial.println(WiFi.localIP());

  server.on("/", HTTP_GET, []() {
    server.send(200, "text/html", getHtml());
  });

  // Define endpoints for turning each device on and off
  for (int i = 1; i <= 9; ++i) {
    server.on("/on" + String(i), HTTP_GET, [i]() {
      controlDevice(i, true);  // true for turning on
      server.send(200, "text/plain", "Turned On Device " + String(i));
    });
    server.on("/off" + String(i), HTTP_GET, [i]() {
      controlDevice(i, false);  // false for turning off
      server.send(200, "text/plain", "Turned Off Device " + String(i));
    });
  }

  server.begin();
}

void loop() {
  server.handleClient();
}

String getHtml() {
  String html = "<html><body><h1>Device Control</h1>";
  for (int i = 1; i <= 9; ++i) {
    html += "<button onclick=\"location.href='/on" + String(i) + "'\">On Device " + String(i) + "</button>";
    html += "<button onclick=\"location.href='/off" + String(i) + "'\">Off Device " + String(i) + "</button><br/>";
  }
  html += "</body></html>";
  return html;
}

void controlDevice(int deviceNum, bool turnOn) {
  String command = "device" + String(deviceNum) + (turnOn ? ":on" : ":off");
  mySerial.println(command);
}
